insert

Function insert 

pub async fn insert(
    conn: &mut PgConnection,
    name: &str,
    path: &str,
    mime: &str,
    uploader: Option<Uuid>,
    size_bytes: Option<i64>,
) -> ModelResult<Uuid>
Records a stored object. size_bytes is the byte count measured while receiving it; None where the upload path does not count bytes.